@@ -637,7 +637,7 @@ class PackageBuildRestrictFormula(set):
             self.update(value)
 
     def __str__(self):
-        return ' '.join('<' + i + '>' for i in sorted(self))
+        return ' '.join('<{}>'.format(i) for i in sorted(self))
 
     def add(self, value):
         if isinstance(value, str):
